summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsfactory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsfactory.h')
-rw-r--r--kjsembed/jsfactory.h108
1 files changed, 54 insertions, 54 deletions
diff --git a/kjsembed/jsfactory.h b/kjsembed/jsfactory.h
index 2b77011b..374b5fde 100644
--- a/kjsembed/jsfactory.h
+++ b/kjsembed/jsfactory.h
@@ -29,10 +29,10 @@
#include <kjs/interpreter.h>
#include <kjs/object.h>
-class TTQEvent;
-class TTQObject;
-class TTQWidget;
-class TTQTextStream;
+class TQEvent;
+class TQObject;
+class TQWidget;
+class TQTextStream;
namespace KParts {
class ReadOnlyPart;
@@ -96,18 +96,18 @@ public:
//
/** Creates an object of the specified class, then returns a proxy. */
- KJS::Object create( KJS::ExecState *exec, const TTQString &classname, const KJS::List &args );
+ KJS::Object create( KJS::ExecState *exec, const TQString &classname, const KJS::List &args );
/** Creates a proxy object for the specified target with the specified context. */
- KJS::Object createProxy( KJS::ExecState *exec, TTQObject *target,
+ KJS::Object createProxy( KJS::ExecState *exec, TQObject *target,
const JSObjectProxy *context=0 ) const;
/** Creates a proxy object for the specified target with the specified context. */
- KJS::Object createProxy( KJS::ExecState *exec, TTQTextStream *target,
+ KJS::Object createProxy( KJS::ExecState *exec, TQTextStream *target,
const JSObjectProxy *context=0 ) const;
/** Creates a proxy object for the specified target with the specified context. */
- KJS::Object createProxy( KJS::ExecState *exec, TTQEvent *target,
+ KJS::Object createProxy( KJS::ExecState *exec, TQEvent *target,
const JSObjectProxy *context ) const;
@@ -115,12 +115,12 @@ public:
* Registers an opaque proxy factory with the with the factory.
* To add an opaque type to the system you need to provide a factory based off of @ref KJSEmbed::Bindings::JSBindingBase
*/
- void registerOpaqueType( const TTQString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
+ void registerOpaqueType( const TQString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
/**
* Remove an opaque type from the system.
*/
- void unregisterOpaqueType( const TTQString &className );
+ void unregisterOpaqueType( const TQString &className );
/**
* When passed an object for a type handled by an Opaque proxy this method
@@ -130,15 +130,15 @@ public:
void extendOpaqueProxy( KJS::ExecState *exec, KJS::Object &proxy) const;
/**
- * Registers a TTQObject proxy factory with the with the factory.
+ * Registers a TQObject proxy factory with the with the factory.
* To add an opaque type to the system you need to provide a factory based off of @ref KJSEmbed::Bindings::JSBindingBase
*/
- void registerObjectType( const TTQString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
+ void registerObjectType( const TQString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
/**
* Remove an opaque type from the system.
*/
- void unregisterObjectType( const TTQString &className );
+ void unregisterObjectType( const TQString &className );
/**
* When passed an object for a type handled by an Opaque proxy this method
@@ -158,22 +158,22 @@ public:
* created is the first offer returned by the trader, and will have the
* specified parent and name.
*/
- KParts::ReadOnlyPart *createROPart( const TTQString &svc, TTQObject *parent=0, const char *name=0 );
+ KParts::ReadOnlyPart *createROPart( const TQString &svc, TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadOnlyPart that views the specified service type and matches
* the specified constraint.
*/
- KParts::ReadOnlyPart *createROPart( const TTQString &svc, const TTQString &constraint,
- TTQObject *parent=0, const char *name=0 );
+ KParts::ReadOnlyPart *createROPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadOnlyPart that views the specified service type and matches
* the specified constraint.
*/
- KParts::ReadOnlyPart *createROPart( const TTQString &svc, const TTQString &constraint,
- TTQObject *parent, const char *name,
- const TTQStringList &args );
+ KParts::ReadOnlyPart *createROPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent, const char *name,
+ const TQStringList &args );
/**
* Creates a ReadWritePart that edits the specified service type. The
@@ -181,34 +181,34 @@ public:
* created is the first offer returned by the trader, and will have the
* specified parent and name.
*/
- KParts::ReadWritePart *createRWPart( const TTQString &svc, TTQObject *parent=0, const char *name=0 );
+ KParts::ReadWritePart *createRWPart( const TQString &svc, TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadWritePart that edits the specified service type and matches
* the specified constraint.
*/
- KParts::ReadWritePart *createRWPart( const TTQString &svc, const TTQString &constraint,
- TTQObject *parent=0, const char *name=0 );
+ KParts::ReadWritePart *createRWPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadWritePart that edits the specified service type and matches
* the specified constraint.
*/
- KParts::ReadWritePart *createRWPart( const TTQString &svc, const TTQString &constraint,
- TTQObject *parent, const char *name,
- const TTQStringList &args );
+ KParts::ReadWritePart *createRWPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent, const char *name,
+ const TQStringList &args );
/**
* Loads the widget defined in the specified .ui file. If the widget
* cannot be created then 0 is returned.
*/
- TTQWidget *loadUI( const TTQString &uiFile, TTQObject *connector=0, TTQWidget *parent=0, const char *name=0 );
+ TQWidget *loadUI( const TQString &uiFile, TQObject *connector=0, TQWidget *parent=0, const char *name=0 );
/**
* Queries KTrader for a plugin that provides the asked for object binding.
*If the binding was added the object is returned, otherwise a KJS::Null is.
*/
- TTQStringList listBindingPlugins( KJS::ExecState *exec, KJS::Object &self);
+ TQStringList listBindingPlugins( KJS::ExecState *exec, KJS::Object &self);
//
// Methods that tell the factory how to handle different classes.
//
@@ -216,48 +216,48 @@ public:
* Adds a binding plugin type to the list of available types the factory can create.
*/
void addBindingPluginTypes(KJS::ExecState *exec, KJS::Object &parent);
- bool isBindingPlugin(const TTQString &classname) const;
+ bool isBindingPlugin(const TQString &classname) const;
/**
* Creates the actual object from the binding plugin.
*/
- KJS::Object createBindingPlugin(KJS::ExecState *exec, const TTQString &classname, const KJS::List &args );
+ KJS::Object createBindingPlugin(KJS::ExecState *exec, const TQString &classname, const KJS::List &args );
/**
* Returns true iff the factory knows the type of proxy to use for the
* class with the name specified.
*/
- bool isSupported( const TTQString &clazz ) const;
+ bool isSupported( const TQString &clazz ) const;
/**
* Returns true iff the class with the specified name is handled with the
- * TTQObject proxy type.
+ * TQObject proxy type.
*/
- bool isTQObject( const TTQString &clazz ) const;
+ bool isTQObject( const TQString &clazz ) const;
/**
* Returns true iff the class with the specified name is handled with the
* value proxy type.
*/
- bool isValue( const TTQString &clazz ) const;
+ bool isValue( const TQString &clazz ) const;
/**
* Returns true iff the class with the specified name is handled with the
* opaque proxy type.
*/
- bool isOpaque( const TTQString &clazz ) const;
+ bool isOpaque( const TQString &clazz ) const;
/**
* Returns the ProxyType of the class with the specified name. If the
* named class is not known to the interpreter then TypeInvalid is
* returned.
*/
- uint proxyType( const TTQString &clazz ) const;
+ uint proxyType( const TQString &clazz ) const;
/**
*Allows adding of an already loaded binding plugin for a certain class type
*
*/
- void addTQObjectPlugin(const TTQString &classname, KJSEmbed::Bindings::JSBindingPlugin* plugin);
+ void addTQObjectPlugin(const TQString &classname, KJSEmbed::Bindings::JSBindingPlugin* plugin);
void addBindingsPlugin(KJS::ExecState *exec, KJS::Object &target) const;
@@ -266,58 +266,58 @@ public:
* class. Note that you can remove support for a type by using this method
* with TypeInvalid.
*/
- void addType( const TTQString &clazz, uint proxytype=JSFactory::TypeTQObject );
+ void addType( const TQString &clazz, uint proxytype=JSFactory::TypeTQObject );
/** Adds the types defined by the factory to the specified parent. */
void addTypes( KJS::ExecState *exec, KJS::Object &parent );
- TTQStringList types() const;
+ TQStringList types() const;
protected:
/** Adds custom bindings to the specified proxy object. */
KJS::Object extendProxy( KJS::ExecState *exec, KJS::Object &target ) const;
/** Creates an instance of the named class and returns it in a JSValueProxy. */
- KJS::Object createValue( KJS::ExecState *exec, const TTQString &cname, const KJS::List &args );
+ KJS::Object createValue( KJS::ExecState *exec, const TQString &cname, const KJS::List &args );
/**
- * Creates an instance of a TTQObject subclass. If the instance cannot be
+ * Creates an instance of a TQObject subclass. If the instance cannot be
* created then 0 is returned.
*/
- TTQObject *create( const TTQString &classname, TTQObject *parent=0, const char *name=0 );
+ TQObject *create( const TQString &classname, TQObject *parent=0, const char *name=0 );
/** Creates an instance of the named class and returns it in a JSOpaqueProxy. */
- KJS::Object createOpaque( KJS::ExecState *exec, const TTQString &cname, const KJS::List &args );
+ KJS::Object createOpaque( KJS::ExecState *exec, const TQString &cname, const KJS::List &args );
- /** Creates an instance of the named binding TTQObject. */
- TTQObject *createBinding( const TTQString &cname, TTQObject *parent, const char *name );
+ /** Creates an instance of the named binding TQObject. */
+ TQObject *createBinding( const TQString &cname, TQObject *parent, const char *name );
/**
- * Creates an instance of the named TTQObject. This method is only used for
+ * Creates an instance of the named TQObject. This method is only used for
* non-widget objects.
*/
- TTQObject *createObject( const TTQString &cname, TTQObject *parent, const char *name );
+ TQObject *createObject( const TQString &cname, TQObject *parent, const char *name );
/**
* Creates an instance of the named TTQWidget. Note that this method is only
* used to create widgets that are not supported by TTQWidgetFactory.
*/
- TTQWidget *createWidget( const TTQString &cname, TTQWidget *parent, const char *name );
+ TQWidget *createWidget( const TQString &cname, TQWidget *parent, const char *name );
private:
/** Adds the types defined by TTQWidgetFactory to the specified parent. */
void addWidgetFactoryTypes( KJS::ExecState *exec, KJS::Object &parent );
- /** Adds support for custom TTQObject types to the specified parent. */
+ /** Adds support for custom TQObject types to the specified parent. */
void addCustomTypes( KJS::ExecState *exec, KJS::Object &parent );
- /** Adds support for TTQObject binding types to the specified parent. */
+ /** Adds support for TQObject binding types to the specified parent. */
void addBindingTypes( KJS::ExecState *exec, KJS::Object &parent );
/**
- * Adds support for any TTQObject types that are known about, but have no
+ * Adds support for any TQObject types that are known about, but have no
* custom support (and no constructor).
*/
void addObjectTypes( KJS::ExecState *exec, KJS::Object &parent );
@@ -329,7 +329,7 @@ private:
private:
KJSEmbedPart *jspart;
JSEventMapper *evmapper;
- TTQMap<TTQString,uint> objtypes;
+ TQMap<TQString,uint> objtypes;
class JSFactoryPrivate *d;
};
@@ -266,58 +266,58 @@ public:
/**
- * Creates an instance of the named TTQWidget. Note that this method is only
- * used to create widgets that are not supported by TTQWidgetFactory.
+ * Creates an instance of the named TQWidget. Note that this method is only
+ * used to create widgets that are not supported by TQWidgetFactory.
*/
@@ -266,58 +266,58 @@ public:
private:
- /** Adds the types defined by TTQWidgetFactory to the specified parent. */
+ /** Adds the types defined by TQWidgetFactory to the specified parent. */
void addWidgetFactoryTypes( KJS::ExecState *exec, KJS::Object &parent );